| Title: | Companion Application for the 'surveydown' Survey Platform |
|---|---|
| Description: | Companion package that supports the 'surveydown' survey platform (<https://surveydown.org>). The default method for working with a 'surveydown' survey is to edit the plain text 'survey.qmd' and 'app.R' files. With 'sdstudio', you can create, preview and manage surveys with a 'shiny' application as a graphical user interface. |
| Authors: | Pingfan Hu [aut, cre, cph]
|
| Maintainer: | Pingfan Hu <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-05-10 09:21:40 UTC |
| Source: | https://github.com/surveydown-dev/sdstudio |
This function launches a Shiny app with 3 tabs: Build, Preview, and Responses. The Build tab includes a template selection interface for creating new surveys.
launch(gssencmode = "auto")launch(gssencmode = "auto")
gssencmode |
Character string. The GSS encryption mode for the database
connection. Defaults to
|
No return value, called for its side effects of launching a Shiny app.
if (interactive()) { # Launch studio (uses "auto" mode by default) launch() # Launch studio with disabled GSS encryption (for VPN connections) launch(gssencmode = "disable") # Launch studio with prefer mode (no fallback) launch(gssencmode = "prefer") }if (interactive()) { # Launch studio (uses "auto" mode by default) launch() # Launch studio with disabled GSS encryption (for VPN connections) launch(gssencmode = "disable") # Launch studio with prefer mode (no fallback) launch(gssencmode = "prefer") }